# Recommender Engine

[![Build Status](https://travis-ci.org/ngshya/recoengi.svg?branch=master)](https://travis-ci.org/ngshya/recoengi)

To install tha package: 

```bash
pip install recoengi
```

Examples are inside the notebook folder. 